package com.huigou.topsun.technology.controller;

import com.huigou.cache.DictUtil;
import com.huigou.topsun.technology.application.TechnologyApplication;
import com.huigou.topsun.technology.domain.query.TechnologyQueryRequest;
import com.huigou.topsun.technology.vo.TechnologyVo;
import com.huigou.uasp.annotation.ControllerMapping;
import com.huigou.uasp.client.CommonController;
import com.huigou.util.SDO;
import org.springframework.stereotype.Controller;

import javax.annotation.Resource;
import java.util.Map;

/**
 * @Auther: xin.lu
 * @Date: 2023/11/23/11:14
 * @Description:
 */
@Controller
@ControllerMapping("/technology")
public class TechnologyController extends CommonController {

    @Resource
    private TechnologyApplication technologyApplication;

    protected String getPagePath() {
        return "/biz/topsun/technology/";
    }


    /**
     * 跳转到查询页面
     * @return
     */
    public String forwardTechnologyList(){
        Map<String, String> processType = DictUtil.getDictionary("processType");
        this.putAttribute("processType",processType);
        return forward("technologyList");
    }

    /**
     * 查询数据列表
     * @return
     */
    public String slicedTechnologyList(){
        SDO sdo = this.getSDO();
        TechnologyQueryRequest queryRequest = sdo.toQueryRequest(TechnologyQueryRequest.class);
        return toResult(technologyApplication.slicedTechnologyList(queryRequest));
    }

    /**
     * 保存工艺
     * @return
     */
    public String saveTechnology(){
        SDO sdo = this.getSDO();
        TechnologyVo technologyVo = sdo.toObject(TechnologyVo.class);
        technologyApplication.saveTechnology(technologyVo);
        return success(technologyVo);
    }

    /**
     * 修改工艺
     * @return
     */
    public String updateTechnology(){
        SDO sdo = this.getSDO();
        TechnologyVo technologyVo = sdo.toObject(TechnologyVo.class);
        technologyApplication.updateTechnologyVo(technologyVo);
        return success(technologyVo);
    }

    /**
     * 删除工艺
     * @return
     */
    public String deleteTechnologyByTechnologyId(){
        SDO sdo = this.getSDO();
        String technologyId = sdo.getString("technologyId");
        technologyApplication.deleteTechnologyVo(technologyId);
        return success();
    }

    /**
     *  工艺新增明细
     * @return
     */
    public String addTechnologyDetail(){
        return forward("technologyDetail");
    }

    /**
     *  查看工艺明细
     * @return
     */
    public String showTechnologyDetail(){
        SDO sdo = this.getSDO();
        String technologyId = sdo.getString("technologyId");
        TechnologyVo technologyVo = technologyApplication.findTechnologyByTechnologyIdId(technologyId);
        return forward("technologyDetail",technologyVo);
    }
}
